@@ -16,10 +16,11 @@ class Broker(object):
             self.set("", "")
 
     @staticmethod
-    def __check():
+    def __check() -> bool:
         import inspect
         if not inspect.stack()[2][1].replace("\\", ".").replace("/", ".").endswith("site-packages.credsafe.broker.py"):
             raise Exception("call outside Broker() is prohibited")
+        return True
 
     def __get(self) -> Dict[str, str]:
         self.__check()
@@ -54,7 +55,7 @@ class Broker(object):
         _[k] = v
         return self.__set(_)
 
-    def rm(self, k):
+    def rm(self, k: str) -> bool:
         _ = self.__get()
         _.pop(k)
         return self.__set(_)
